=====
Usage
=====

To use Zertrin Python Toolbox in a project::

    import zkpytb

Usually, you only need a handful of functions from the toolbox::

    from zkpytb.dicts import mergedicts
    from zkpytb.pandas import mad, percentile
